@@ -342,7 +342,7 @@ sub failure {
     # update session data about this form
     $self->to_session();
 
-    session(form_errors => '<ul>' . join('', map {"<li>$_->[1]</li>"} @{$args{errors} || []}) . '</ul>');
+    session(form_errors => '<ul>' . join('', map {"<li>$_</li>"} CORE::values %{$args{errors} || {}}) . '</ul>');
 
     session(form_data => $args{data});
 
@@ -522,7 +522,7 @@ L<http://search.cpan.org/dist/Dancer-Template-TemplateFlute/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011-2014 Stefan Hornburg (Racke).
+Copyright 2011-2015 Stefan Hornburg (Racke).
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
