@@ -14,7 +14,7 @@ use Dancer::Config;
 
 use base 'Dancer::Template::Abstract';
 
-our $VERSION = '0.0140';
+our $VERSION = '0.0141';
 
 =head1 NAME
 
@@ -22,7 +22,7 @@ Dancer::Template::TemplateFlute - Template::Flute wrapper for Dancer
 
 =head1 VERSION
 
-Version 0.0140
+Version 0.0141
 
 =head1 DESCRIPTION
 
@@ -206,6 +206,12 @@ Example configuration:
     template_flute:
       check_dangling: 1
 
+When the environment is set to C<development> this feature is turned
+on by default. You can silence the logs by setting:
+
+  engines:
+    template_flute:
+      disable_check_dangling: 1
 
 =head2 FORMS
 
@@ -498,7 +504,10 @@ sub render ($$$) {
 
 	$html = $flute->process();
 
-    if ($self->config->{check_dangling}) {
+    if ($self->config->{check_dangling} or
+        ($tokens->{settings}->{environment} eq 'development' &&
+         !$self->config->{disable_check_dangling})) {
+
         if (my @warnings = $flute->specification->dangling) {
             foreach my $warn (@warnings) {
                 Dancer::Logger::debug('Found dangling element '
@@ -626,7 +635,7 @@ L<http://search.cpan.org/dist/Dancer-Template-TemplateFlute/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011-2014 Stefan Hornburg (Racke) <racke@linuxia.de>.
+Copyright 2011-2015 Stefan Hornburg (Racke) <racke@linuxia.de>.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
